@@ -1,33 +1,62 @@
-#' Correlation Matrix with Statistical Significance Testing
+#' Correlation Matrix
 #'
-#' This function computes a correlation matrix and computes significance values (\emph{p}-values) for testing the hypothesis
-#' H0: \eqn{\rho} = 0 for all possible pairs of variables.
+#' This function computes a correlation matrix based on Pearson product-moment
+#' correlation coefficient, Spearman's rank-order correlation coefficient,
+#' Kendall's Tau-b correlation coefficient, or Kendall-Stuart's Tau-c correlation
+#' coefficient and computes significance values (\emph{p}-values) for testing the
+#' hypothesis H0: \eqn{\rho} = 0 for all pairs of variables.
+#'
+#' Note that unlike the \code{\link[stats:cor.test]{cor.test}} function, this function
+#' does not compute an exact \emph{p}-value for Spearman's rank-order correlation
+#' coefficient or Kendall's Tau-b correlation coefficient, but uses the asymptotic
+#' \emph{t} approximation.
+#'
+#' Statistically significant correlation coefficients are shown in boldface on the
+#' console (\code{sig = TRUE}). However, this option is not supported when using
+#' R Markdown, i.e., the argument \code{sig} will switch to \code{FALSE}.
 #'
 #' @param x            a matrix or data frame.
-#' @param method       a character vector indicating which correlation coefficient is to be computed, i.e.
-#'                     \code{"pearson"} for Pearson product-moment correlation coefficient (default),
-#'                     \code{"spearman"} for Spearman's rank-order correlation coefficient, \code{kendall-b} for
-#'                     Kendall's Tau-b correlation coefficient or \code{kendall-c} for Kendall-Stuart's Tau-c
-#'                     correlation coefficient.
-#' @param na.omit      logical: if \code{TRUE}, incomplete cases are removed before conducting the analysis
-#'                     (i.e., listwise deletion); if \code{FALSE} (default), pairwise deletion is used.
-#' @param group        a numeric vector, character vector of factor as grouping variable to show results for
-#'                     each group separately, i.e., upper triangular for one group and lower triangular for
-#'                     another group. Note that the grouping variable is limited to two groups.
-#' @param print        a character string or character vector indicating which additional results to show,
-#'                     i.e. \code{"all"}, for all additional results: \code{"n"} for the sample sizes, and
-#'                     \code{"p"} for \emph{p}-values.
-#' @param tri          a character string indicating which triangular of the matrix to show on the console,
-#'                     i.e., \code{both} for upper and lower triangular, \code{lower} (default) for the
-#'                     lower triangular, and \code{upper} for the upper triangular.
-#' @param p.adj        a character string indicating an adjustment method for multiple testing based on \code{\link{p.adjust}},
-#'                     i.e.,  \code{none} (default), \code{bonferroni}, \code{holm}, \code{hochberg}, \code{hommel},
+#' @param method       a character vector indicating which correlation coefficient
+#'                     is to be computed, i.e. \code{"pearson"} for Pearson product-moment
+#'                     correlation coefficient (default), \code{"spearman"} for Spearman's
+#'                     rank-order correlation coefficient, \code{kendall-b} for Kendall's
+#'                     Tau-b correlation coefficient or \code{kendall-c} for Kendall-Stuart's
+#'                     Tau-c correlation coefficient.
+#' @param na.omit      logical: if \code{TRUE}, incomplete cases are removed before
+#'                     conducting the analysis (i.e., listwise deletion); if \code{FALSE}
+#'                     (default), pairwise deletion is used.
+#' @param group        a numeric vector, character vector of factor as grouping variable
+#'                     to show results for each group separately, i.e., upper triangular
+#'                     for one group and lower triangular for another group. Note that the
+#'                     grouping variable is limited to two groups.
+#' @param sig          logical: if \code{TRUE} (default), statistically significant
+#'                     correlation coefficients are shown in boldface on the console.
+#' @param alpha        a numeric value between 0 and 1 indicating the significance
+#'                     level at which correlation coefficients are printed boldface
+#'                     when \code{sig = TRUE}.
+#' @param print        a character string or character vector indicating which results
+#'                     to show on the console, i.e. \code{"all"} for all results,
+#'                     \code{"cor"} for correlation coefficients, \code{"n"} for the
+#'                     sample sizes, \code{"stat"} for the test statistic, \code{"df"}
+#'                     for the degrees of freedom, and \code{"p"} for \emph{p}-values.
+#' @param tri          a character string indicating which triangular of the matrix
+#'                     to show on the console, i.e., \code{both} for upper and lower
+#'                     triangular, \code{lower} (default) for the lower triangular,
+#'                     and \code{upper} for the upper triangular.
+#' @param p.adj        a character string indicating an adjustment method for multiple
+#'                     testing based on \code{\link{p.adjust}}, i.e., \code{none} (default),
+#'                     \code{bonferroni}, \code{holm}, \code{hochberg}, \code{hommel},
 #'                     \code{BH}, \code{BY}, or \code{fdr}.
-#' @param digits       an integer value indicating the number of decimal places to be used for displaying
-#'                     correlation coefficients.
-#' @param p.digits     an integer value indicating the number of decimal places to be used for displaying \emph{p}-values.
+#' @param continuity   logical: if \code{TRUE} (default), continuity correction is
+#'                     used for testing Spearman's rank-order correlation coefficient
+#'                     and Kendall's Tau-b correlation.
+#' @param digits       an integer value indicating the number of decimal places to be
+#'                     used for displaying correlation coefficients.
+#' @param p.digits     an integer value indicating the number of decimal places to be
+#'                     used for displaying \emph{p}-values.
 #' @param as.na        a numeric vector indicating user-defined missing values,
-#'                     i.e. these values are converted to \code{NA} before conducting the analysis.
+#'                     i.e. these values are converted to \code{NA} before conducting
+#'                     the analysis.
 #' @param check        logical: if \code{TRUE}, argument specification is checked.
 #' @param output       logical: if \code{TRUE}, output is shown on the console.
 #'
@@ -36,17 +65,18 @@
 #'
 #' @seealso
 #' \code{\link{cohens.d}}, \code{\link{cor.cont}}, \code{\link{cor.cramer}},
-#' \code{\link{multilevel.icc}}, \code{\link{cor.phi}}, \code{\link{na.auxiliary}}, \code{\link{size.cor}}.
+#' \code{\link{multilevel.icc}}, \code{\link{cor.phi}}, \code{\link{na.auxiliary}},
+#' \code{\link{size.cor}}.
 #'
 #' @references
-#' Rasch, D., Kubinger, K. D., & Yanagida, T. (2011). \emph{Statistics in psychology - Using R and SPSS}.
-#' John Wiley & Sons.
+#' Rasch, D., Kubinger, K. D., & Yanagida, T. (2011). \emph{Statistics in psychology
+#' - Using R and SPSS}. John Wiley & Sons.
 #'
 #' @return
-#' Returns an object of class \code{misty.object}, which is a list with following entries:
-#' function call (\code{call}), type of analysis \code{type}, matrix or data frame specified in
-#' \code{x} (\code{data}), specification of function arguments (\code{args}), and
-#' list with results (\code{result}).
+#' Returns an object of class \code{misty.object}, which is a list with following
+#' entries: function call (\code{call}), type of analysis \code{type}, matrix or
+#' data frame specified in \code{x} (\code{data}), specification of function
+#' arguments (\code{args}), and list with results (\code{result}).
 #'
 #' @export
 #'
@@ -58,6 +88,9 @@
 #'                   z = c(1, 3, 1, NA, 2, 4, 6, 5, 9, 6),
 #'                   stringsAsFactors = TRUE)
 #'
+#' # Pearson product-moment correlation coefficient using pairwise deletion
+#' cor.matrix(dat[, c("x", "y")])
+#'
 #' # Pearson product-moment correlation coefficient matrix using pairwise deletion
 #' cor.matrix(dat[, c("x", "y", "z")])
 #'
@@ -67,9 +100,13 @@
 #' # Kendall's Tau-b correlation matrix using pairwise deletion
 #' cor.matrix(dat[, c("x", "y", "z")], method = "kendall-b")
 #'
-#' # Kendall's Tau-c correlation matrix using pairwise deletion
+#' # Kendall-Stuart's Tau-c correlation matrix using pairwise deletion
 #' cor.matrix(dat[, c("x", "y", "z")], method = "kendall-c")
 #'
+#' # Pearson product-moment correlation coefficient matrix using pairwise deletion
+#' # highlight statistically significant result at alpha = 0.10
+#' cor.matrix(dat[, c("x", "y", "z")], alpha = 0.10)
+#'
 #' # Pearson product-moment correlation coefficient matrix using pairwise deletion,
 #' # print sample size and significance values
 #' cor.matrix(dat[, c("x", "y", "z")], print = "all")
@@ -82,13 +119,20 @@
 #' # print sample size and significance values with Bonferroni correction
 #' cor.matrix(dat[, c("x", "y", "z")], na.omit = TRUE, print = "all", p.adj = "bonferroni")
 #'
+#' # Pearson product-moment correlation coefficient using pairwise deletion,
+#' # results for group "a" and "b" separately
+#' cor.matrix(dat[, c("x", "y")], group = dat$group)
+#'
 #' # Pearson product-moment correlation coefficient matrix using pairwise deletion,
 #' # results for group "a" and "b" separately
 #' cor.matrix(dat[, c("x", "y", "z")], group = dat$group, print = "all")
-cor.matrix <- function(x, method = c("pearson", "spearman", "kendall-b", "kendall-c"), na.omit = FALSE,
-                       group = NULL, print = c("all", "cor", "n", "p"), tri = c("both", "lower", "upper"),
+cor.matrix <- function(x, method = c("pearson", "spearman", "kendall-b", "kendall-c"),
+                       na.omit = FALSE, group = NULL, sig = TRUE, alpha = 0.05,
+                       print = c("all", "cor", "n", "stat", "df", "p"),
+                       tri = c("both", "lower", "upper"),
                        p.adj = c("none", "bonferroni", "holm", "hochberg", "hommel", "BH", "BY", "fdr"),
-                       digits = 2, p.digits = 3, as.na = NULL, check = TRUE, output = TRUE) {
+                       continuity = TRUE, digits = 2, p.digits = 3, as.na = NULL,
+                       check = TRUE, output = TRUE) {
 
   ####################################################################################
   # Data
@@ -126,6 +170,10 @@ cor.matrix <- function(x, method = c("pearson", "spearman", "kendall-b", "kendal
   # Coerce to a data frame
   x <- as.data.frame(x, stringsAsFactors = FALSE)
 
+  #......
+  # Convert 'x' into a vector
+  group <- unlist(group, use.names = FALSE)
+
   ####################################################################################
   # Input Check
 
@@ -230,10 +278,26 @@ cor.matrix <- function(x, method = c("pearson", "spearman", "kendall-b", "kendal
     }
 
     #......
-    # Check input 'print'
-    if (isTRUE(any(!print %in% c("all", "cor", "n", "p")))) {
+    # Check input 'sig'
+    if (isTRUE(!is.logical(sig))) {
 
-      stop("Character string(s) in the argument 'print' does not match with \"all\", \"cor\", \"n\", or \"p\".",
+      stop("Please specify TRUE or FALSE for the argument 'sig'.", call. = FALSE)
+
+    }
+
+    #......
+    # Check input 'alpha'
+    if (isTRUE(alpha >= 1L || alpha <= 0L)) {
+
+      stop("Please specify a number between 0 and 1 for the argument 'alpha'.", call. = FALSE)
+
+    }
+
+    #......
+    # Check input 'print'
+    if (isTRUE(any(!print %in% c("all", "cor", "n", "stat", "df", "p")))) {
+
+      stop("Character string(s) in the argument 'print' does not match with \"all\", \"cor\", \"n\", \"stat\", \"df\", or \"p\".",
            call. = FALSE)
 
     }
@@ -322,6 +386,11 @@ cor.matrix <- function(x, method = c("pearson", "spearman", "kendall-b", "kendal
 
   }
 
+  #......
+  # Missing data
+
+  attr(x, "missing") <- any(is.na(x))
+
   #----------------------------------------
   # Correlation coefficient
 
@@ -388,10 +457,10 @@ cor.matrix <- function(x, method = c("pearson", "spearman", "kendall-b", "kendal
 
       #-----------------------------------------
       # If n > 2
-      if (isTRUE(x.n > 2L)) {
+      if (isTRUE(x.n > 2L & x.nrow > 1L & x.ncol > 1L)) {
 
         # Asymptotic standard error
-        sigma <- sqrt(4L * x.m^2L / ((x.m - 1L)^2L * x.n^4L) * (sum(x.table * (pi.c - pi.d)^2L) - 4L * (x.con - x.dis)^2L/x.n))
+        sigma <- sqrt(4L * x.m^2L / ((x.m - 1L)^2L * x.n^4L) * (sum(x.table * (pi.c - pi.d)^2L) - 4L * (x.con - x.dis)^2L / x.n))
 
         # Test statistic
         z <- tau.c / sigma
@@ -402,6 +471,7 @@ cor.matrix <- function(x, method = c("pearson", "spearman", "kendall-b", "kendal
       } else {
 
         sigma <- NA
+        z <- NA
         pval <- NA
 
       }
@@ -409,11 +479,11 @@ cor.matrix <- function(x, method = c("pearson", "spearman", "kendall-b", "kendal
       ####################################################################################
       # Return object
 
-      object <- list(data = data.frame(xx, yy, stringsAsFactors = FALSE),
-                     result = list(tau.c = tau.c,
+      object <- list(result = list(tau.c = tau.c,
                                    n = x.n,
                                    sigma = sigma,
-                                   z = z,
+                                   stat = z,
+                                   df = NA,
                                    pval = pval))
 
       return(object)
@@ -422,6 +492,136 @@ cor.matrix <- function(x, method = c("pearson", "spearman", "kendall-b", "kendal
 
   }
 
+  #----------------------------------------
+  # Internal function: Significance testing Pearson correlation
+  .internal.cor.test.pearson <- function(x, y) {
+
+    # At least three cases
+    if (isTRUE(nrow(na.omit(data.frame(x = x, y = y))) >= 3L)) {
+
+      result.cor.test <- suppressWarnings(cor.test(x, y, method = "pearson"))
+
+      object <- list(stat = result.cor.test$statistic,
+                     df = result.cor.test$parameter,
+                     pval = result.cor.test$p.value)
+
+    # Less than three cases
+    } else {
+
+      object <- list(stat = NA, df = NA, pval = NA)
+
+    }
+
+    return(object)
+
+  }
+
+  #----------------------------------------
+  # Internal function: Significance testing Spearman correlation
+
+  .internal.cor.test.spearman <- function(x, y, continuity) {
+
+    # Complete data
+    xy.dat <- na.omit(data.frame(x = x, y = y))
+
+    # Number of cases
+    n <- nrow(xy.dat)
+
+    # At least three cases
+    if (isTRUE(n >= 3L)) {
+
+      # Correlation coefficient
+      r <- cor(xy.dat[, c("x", "y")], method = "spearman")[1, 2]
+
+      # Continuity correction
+      if (isTRUE(continuity)) {
+
+        r <- 1 - ((n^3 - n) * (1 - r) / 6) / (((n * (n^2 - 1)) / 6) + 1)
+
+      }
+
+      # Test statistic
+      stat <- r * sqrt((n - 2) / (1 - r^2))
+
+      # Degrees of freedom
+      df <- n - 2
+
+      # p-value
+      pval <- min(pt(stat, df = df),
+                  pt(stat, df = df, lower.tail = FALSE))*2L
+
+      # Return object
+      object <- list(stat = stat, df = df, pval = pval)
+
+    # Less than three cases
+    } else {
+
+      # Return object
+      object <- list(stat = NA, df = NA, pval = NA)
+
+    }
+
+    return(object)
+
+  }
+
+  #----------------------------------------
+  # Internal function: Significance testing Kendall Tau-b
+
+  .internal.cor.test.kendall.b <- function(x, y, continuity) {
+
+    # Complete data
+    xy.dat <- na.omit(data.frame(x = x, y = y))
+
+    # Number of cases
+    n <- nrow(xy.dat)
+
+    # At least three cases
+    if (isTRUE(n >= 3L)) {
+
+      # Correlation coefficient
+      r <- cor(xy.dat[, c("x","y")], method = "kendall")[1, 2]
+
+      xties <- table(x[duplicated(x)]) + 1
+      yties <- table(y[duplicated(y)]) + 1
+      T0 <- n * (n - 1)/2
+      T1 <- sum(xties * (xties - 1))/2
+      T2 <- sum(yties * (yties - 1))/2
+      S <- r * sqrt((T0 - T1) * (T0 - T2))
+      v0 <- n * (n - 1) * (2 * n + 5)
+      vt <- sum(xties * (xties - 1) * (2 * xties + 5))
+      vu <- sum(yties * (yties - 1) * (2 * yties + 5))
+      v1 <- sum(xties * (xties - 1)) * sum(yties * (yties - 1))
+      v2 <- sum(xties * (xties - 1) * (xties - 2)) * sum(yties * (yties - 1) * (yties - 2))
+
+      var_S <- (v0 - vt - vu) / 18 + v1 / (2 * n * (n - 1)) + v2 / (9 * n * (n - 1) * (n - 2))
+
+      # Continuity correction
+      if (isTRUE(continuity)) {
+
+        S <- sign(S) * (abs(S) - 1)
+
+      }
+
+      # Test staistic
+      stat <- S / sqrt(var_S)
+
+      # p-value
+      pval <-  min(pnorm(stat),
+                   pnorm(stat, lower.tail = FALSE))*2L
+
+      object <- list(stat = stat, df = NA, pval = pval)
+
+    # Less than three cases
+    } else {
+
+      object <- list(stat = NA, df = NA, pval = NA)
+    }
+
+    return(object)
+
+  }
+
   #-----------------------------------------
   # Listwise deletion
 
@@ -447,14 +647,48 @@ cor.matrix <- function(x, method = c("pearson", "spearman", "kendall-b", "kendal
   #-----------------------------------------
   # Print correlation, sample size or significance values
 
-  if (isTRUE(all(c("all", "cor", "n", "p") %in% print))) { print <- "cor" }
+  if (isTRUE(all(c("all", "cor", "n", "stat", "df", "p") %in% print))) { print <- "cor" }
 
-  if (isTRUE(length(print) == 1 && "all" %in% print)) { print <- c("cor", "n", "p") }
+  if (isTRUE(method %in% c("pearson", "spearman"))) {
+
+    if (isTRUE(length(print) == 1 && "all" %in% print)) { print <- c("cor", "n", "stat", "df", "p") }
+
+  } else {
+
+    if (isTRUE(length(print) == 1 && "all" %in% print)) { print <- c("cor", "n", "stat", "p") }
+
+  }
+
+  #......
+  # Check input 'print'
+  if (isTRUE(print == "df" & method %in% c("kendall-b", "kendall-c"))) {
+
+    switch(method, "kendall-b" = {
+
+      stop("There are no degrees of freedom (df) for testing the Kendall's Tau-b correlation coefficient.",
+           call. = FALSE)
+
+    }, "kendall-c" = {
+
+      stop("There are no degrees of freedom (df) for testing the Kendall-Stuart's Tau-c correlation coefficient.",
+           call. = FALSE)
+
+    })
+
+  }
 
   #-----------------------------------------
   # Print triangular
 
-  tri <- ifelse(all(c("both", "lower", "upper") %in% tri), "lower", tri)
+  if (isTRUE(is.null(group))) {
+
+    tri <- ifelse(all(c("both", "lower", "upper") %in% tri), "lower", tri)
+
+  } else {
+
+    tri <- "both"
+
+  }
 
   #-----------------------------------------
   # Adjustment method for multiple testing
@@ -467,14 +701,9 @@ cor.matrix <- function(x, method = c("pearson", "spearman", "kendall-b", "kendal
   comb <- combn(seq_len(ncol(x)), m = 2L)
 
   #-----------------------------------------
-  # Sample size matrix
+  # Sample size, t statistic, df, and p-value matrix
 
-  n.mat <- matrix(NA, ncol = ncol(x), nrow = ncol(x), dimnames = list(colnames(x), colnames(x)))
-
-  #-----------------------------------------
-  # p-values matrix
-
-  p.mat <- n.mat
+  p.mat <- df.mat <- stat.mat <- n.mat <- matrix(NA, ncol = ncol(x), nrow = ncol(x), dimnames = list(colnames(x), colnames(x)))
 
   ####################################################################################
   # Main Function
@@ -492,24 +721,22 @@ cor.matrix <- function(x, method = c("pearson", "spearman", "kendall-b", "kendal
 
       cor.mat <- suppressWarnings(cor(x, use = "pairwise.complete.obs", method = method))
 
-    }
-
     # Kendall Tau-b
-    if (isTRUE(method == "kendall-b")) {
+    } else if (isTRUE(method == "kendall-b")) {
 
       cor.mat <- suppressWarnings(cor(x, use = "pairwise.complete.obs", method = "kendall"))
 
-    }
-
     # Kendall-Stuart Tau-c
-    if (isTRUE(method == "kendall-c")) {
+    } else if (isTRUE(method == "kendall-c")) {
+
+      cor.test.res <- apply(comb, 2, function(y) suppressWarnings(.internal.tau.c(x[, y[1L]], x[, y[2L]])$result))
 
       cor.mat <- matrix(NA, ncol = ncol(x), nrow = ncol(x), dimnames = list(colnames(x), colnames(x)))
 
-      cor.mat[lower.tri(cor.mat)] <- apply(comb, 2, function(y) suppressWarnings(.internal.tau.c(x[, y[1L]], x[, y[2L]])$result$tau.c))
+      cor.mat[lower.tri(cor.mat)] <- sapply(cor.test.res, function(y) y$tau.c)
       cor.mat[upper.tri(cor.mat)] <- t(cor.mat)[upper.tri(cor.mat)]
 
-      diag(cor.mat) <- 1
+      diag(cor.mat) <- 1L
 
     }
 
@@ -518,7 +745,7 @@ cor.matrix <- function(x, method = c("pearson", "spearman", "kendall-b", "kendal
 
     if (!isTRUE(na.omit)) {
 
-      n <- apply(comb, 2, function(y) nrow(na.omit(cbind(x[, y[1]], x[, y[2L]]))))
+      n <- apply(comb, 2, function(y) nrow(na.omit(cbind(x[, y[1L]], x[, y[2L]]))))
 
     } else {
 
@@ -530,28 +757,33 @@ cor.matrix <- function(x, method = c("pearson", "spearman", "kendall-b", "kendal
     n.mat[upper.tri(n.mat)] <- t(n.mat)[upper.tri(n.mat)]
 
     #........................................
-    # p-values
+    # Test statistic, df and p-values
 
     # Product-moment or Spearman correlation coefficient
-    if (isTRUE(!method %in% c("kendall-b", "kendall-c"))) {
+    switch(method, "pearson" = {
 
-      pval <- apply(comb, 2, function(y) suppressWarnings(cor.test(x[, y[1L]], x[, y[2L]], method = method))$p.value)
+      cor.test.res <- apply(comb, 2, function(y) suppressWarnings(.internal.cor.test.pearson(x[, y[1L]], x[, y[2L]])))
 
-    }
+    # Spearman correlation coefficient
+    }, "spearman" = {
+
+      cor.test.res <- apply(comb, 2, function(y) suppressWarnings(.internal.cor.test.spearman(x[, y[1L]], x[, y[2L]], continuity = continuity)))
 
     # Kendall Tau-b
-    if (isTRUE(method == "kendall-b")) {
+    }, "kendall-b" = {
 
-      pval <- apply(comb, 2, function(y) suppressWarnings(cor.test(x[, y[1L]], x[, y[2L]], method = "kendall"))$p.value)
+      cor.test.res <- apply(comb, 2, function(y) suppressWarnings(.internal.cor.test.kendall.b(x[, y[1L]], x[, y[2L]], continuity = continuity)))
 
-    }
+    })
 
-    # Kendall-Stuart Tau-c
-    if (isTRUE(method == "kendall-c")) {
+    # Test statistic
+    stat <- sapply(cor.test.res, function(y) y$stat)
 
-      pval <- apply(comb, 2, function(y) suppressWarnings(.internal.tau.c(x[, y[1L]], x[, y[2L]])$result$pval))
+    # Degrees of freedom
+    df <- sapply(cor.test.res, function(y) y$df)
 
-    }
+    # p-values
+    pval <- sapply(cor.test.res, function(y) y$pval)
 
     ###
 
@@ -562,6 +794,12 @@ cor.matrix <- function(x, method = c("pearson", "spearman", "kendall-b", "kendal
 
     }
 
+    stat.mat[lower.tri(stat.mat)] <- stat
+    stat.mat[upper.tri(stat.mat)] <- t(stat.mat)[upper.tri(stat.mat)]
+
+    df.mat[lower.tri(df.mat)] <- df
+    df.mat[upper.tri(df.mat)] <- t(df.mat)[upper.tri(df.mat)]
+
     p.mat[lower.tri(p.mat)] <- pval
     p.mat[upper.tri(p.mat)] <- t(p.mat)[upper.tri(p.mat)]
 
@@ -571,7 +809,7 @@ cor.matrix <- function(x, method = c("pearson", "spearman", "kendall-b", "kendal
   } else {
 
     # At least 3 observations
-    if (isTRUE(any(table(group) < 3))) {
+    if (isTRUE(any(table(group) < 3L))) {
 
       stop("There are not enough observations for each group specified in 'group' to compute the correlation matrix separately.",
            call. = FALSE)
@@ -582,20 +820,27 @@ cor.matrix <- function(x, method = c("pearson", "spearman", "kendall-b", "kendal
     x.group <- split(x, f = group)
 
     object.g1 <- misty::cor.matrix(x.group[[1]], method = method, na.omit = na.omit, group = NULL,
-                                   digits = digits, print = print, tri = tri, p.adj = p.adj, p.digits = p.digits,
-                                   check = FALSE, output = FALSE)
+                                   digits = digits, continuity = continuity, print = print, tri = tri,
+                                   p.adj = p.adj, p.digits = p.digits, check = FALSE, output = FALSE)
 
     object.g2 <- misty::cor.matrix(x.group[[2]], method = method, na.omit = na.omit, group = NULL,
-                                   digits = digits, print = print, tri = tri, p.adj = p.adj, p.digits = p.digits,
-                                   check = FALSE, output = FALSE)
+                                   digits = digits, continuity = continuity, print = print, tri = tri,
+                                   p.adj = p.adj, p.digits = p.digits, check = FALSE, output = FALSE)
 
     #........................................
-    # Correlation matrix, Sample size, and p-values
+    # Data frame, correlation matrix, sample size, and p-values
+
+    x <- data.frame(.group = group, x)
+
+    #......
+    # Missing data
+
+    attr(x, "missing") <- any(is.na(x))
 
     cor.mat <- object.g1$result$cor
-
     n.mat <- object.g1$result$n
-
+    stat.mat <- object.g1$result$stat
+    df.mat <- object.g1$result$df
     p.mat <- object.g1$result$p
 
     #........................................
@@ -603,6 +848,8 @@ cor.matrix <- function(x, method = c("pearson", "spearman", "kendall-b", "kendal
 
     cor.mat[upper.tri(cor.mat)] <- object.g2$result$cor[upper.tri(object.g2$result$cor)]
     n.mat[upper.tri(n.mat)] <- object.g2$result$n[upper.tri(object.g2$result$n)]
+    stat.mat[upper.tri(stat.mat)] <- object.g2$result$stat[upper.tri(object.g2$result$stat)]
+    df.mat[upper.tri(df.mat)] <- object.g2$result$df[upper.tri(object.g2$result$df)]
     p.mat[upper.tri(p.mat)] <- object.g2$result$p[upper.tri(object.g2$result$p)]
 
   }
@@ -613,10 +860,11 @@ cor.matrix <- function(x, method = c("pearson", "spearman", "kendall-b", "kendal
   object <- list(call = match.call(),
                  type = "cor.matrix",
                  data = x,
-                 args = list(method = method, na.omit = na.omit, group = group, print = print,
-                             tri = tri, p.adj = p.adj, digits = digits, p.digits = p.digits,
-                             as.na = as.na, check = check, output = output),
-                 result = list(cor = cor.mat, n = n.mat, p = p.mat))
+                 args = list(method = method, na.omit = na.omit,
+                             sig = sig, alpha = alpha, print = print, tri = tri,
+                             p.adj = p.adj, continuity = continuity, digits = digits,
+                             p.digits = p.digits, as.na = as.na, check = check, output = output),
+                 result = list(cor = cor.mat, n = n.mat, stat = stat.mat, df = df.mat,p = p.mat))
 
   class(object) <- "misty.object"
 
