@@ -54,7 +54,7 @@ read.mplus <- function(file, sep = "", input = NULL, print = FALSE, return.var =
   #----------------------------------------
   # Check input 'input'
 
-  if (isTRUE(return.var) && missing(input)) {
+  if (isTRUE(return.var && missing(input))) {
 
     stop("Please specify a character string indicating the name of the Mplus input/output file for the argument 'input'.",
          call. = FALSE)
@@ -64,7 +64,7 @@ read.mplus <- function(file, sep = "", input = NULL, print = FALSE, return.var =
   #----------------------------------------
   # Mplus input/output file
 
-  if (!is.null(input)) {
+  if (isTRUE(!is.null(input))) {
 
     #......
     # File extension .inp or .out
@@ -84,7 +84,7 @@ read.mplus <- function(file, sep = "", input = NULL, print = FALSE, return.var =
 
     #......
     # Remove comments
-    if (length(grep("!", inp.variable)) > 0L) {
+    if (isTRUE(length(grep("!", inp.variable)) > 0L)) {
 
       inp.comments <- inp.variable[grep("!", inp.variable)]
 
@@ -94,9 +94,48 @@ read.mplus <- function(file, sep = "", input = NULL, print = FALSE, return.var =
 
     #......
     # Extract variable names
-    varnames <- misty::stromit(unlist(strsplit(misty::trim(gsub("VARIABLE:|variable:|Variable:|NAMES ARE|names ARE|Names ARE|NAMES are|names are|Names are|NAMES Are|names Are|Names Are|NAMES =|names =|Names =|;|\n|\t|\r|\r\n", "",
+    varnames <- misty::chr.omit(unlist(strsplit(misty::chr.trim(gsub("VARIABLE:|variable:|Variable:|NAMES ARE|names ARE|Names ARE|NAMES are|names are|Names are|NAMES Are|names Are|Names Are|NAMES =|names =|Names =|;|\n|\t|\r|\r\n", "",
                                                                 inp.variable)), " ")), check = FALSE)
 
+    # Consecutive variable names
+    if (isTRUE(length(grep("-", varnames)) > 0L)) {
+
+      # Variable positive with consecutive variable names
+      convar.pos <- grep("-", varnames)
+      convar.list <- NULL
+      for (i in convar.pos) {
+
+        # Split consecutive variable names to start and end
+        temp <- unlist(strsplit(varnames[i], "-"))
+
+        # Split consecutive variable names
+        split1.chr <- unlist(strsplit(temp[1], ""))
+        split2.chr <- unlist(strsplit(temp[2], ""))
+
+        # Extract number of digits
+        rle1 <- rle(suppressWarnings(rev(!is.na(as.numeric(split1.chr)))))$lengths[1]
+        rle2 <- rle(suppressWarnings(rev(!is.na(as.numeric(split2.chr)))))$lengths[1]
+
+        # Extract starting and ending number
+        start.n <- as.numeric(paste(rev(rev(split1.chr)[1:rle1]), collapse = ""))
+        end.n <- as.numeric(paste(rev(rev(split2.chr)[1:rle2]), collapse = ""))
+
+        # Expand variable names
+        convar.list[[i]] <- paste0(paste(rev(rev(split1.chr)[-c(1:rle1)]), collapse = ""), start.n:end.n)
+
+      }
+
+      # Combine variables names and extended consecutive variable names
+      for (i in (1:length(varnames))[!1:length(varnames) %in% convar.pos]) {
+
+        convar.list[[i]] <- varnames[i]
+
+      }
+
+      varnames <- unlist(convar.list)
+
+    }
+
   }
 
   #----------------------------------------
@@ -115,7 +154,7 @@ read.mplus <- function(file, sep = "", input = NULL, print = FALSE, return.var =
 
     #......
     # Check input 'file'
-    if (missing(file)) {
+    if (isTRUE(missing(file))) {
 
       stop("Please specify a character string indicating the name of the Mplus data file for the argument 'file'.",
            call. = FALSE)
@@ -130,7 +169,7 @@ read.mplus <- function(file, sep = "", input = NULL, print = FALSE, return.var =
 
     #......
     # Check if file exists
-    if (!file.exists(file)) {
+    if (isTRUE(!file.exists(file))) {
 
       stop(paste0("Unable to open Mplus data file: ", sQuote(file), " does not exist."),
            call. = FALSE)
@@ -139,7 +178,7 @@ read.mplus <- function(file, sep = "", input = NULL, print = FALSE, return.var =
 
     #......
     # Check input 'check'
-    if (!is.logical(check)) {
+    if (isTRUE(!is.logical(check))) {
 
       stop("Please specify TRUE or FALSE for the argument 'check'.", call. = FALSE)
 
@@ -155,7 +194,7 @@ read.mplus <- function(file, sep = "", input = NULL, print = FALSE, return.var =
       #......
       # Dot (.) as decimal separator
 
-      if (length(grep(",", df.lines)) > 0L) {
+      if (isTRUE(length(grep(",", df.lines)) > 0L)) {
 
         stop(paste0("Data file ", file, " uses the wrong decimal separator, i.e., \",\" instead of \".\""),
              call. = FALSE)
@@ -166,7 +205,7 @@ read.mplus <- function(file, sep = "", input = NULL, print = FALSE, return.var =
       # Number of rows
       df.lines.nrows <- unname(vapply(vapply(df.lines, function(y) strsplit(y, " "), FUN.VALUE = list(1L)), length, FUN.VALUE = 1L))
 
-      if (length(unique(df.lines.nrows)) != 1L) {
+      if (isTRUE(length(unique(df.lines.nrows)) != 1L)) {
 
         stop(paste0("Data file ", file, " does not have the same number of entries in each line."), call. = FALSE)
 
@@ -175,12 +214,12 @@ read.mplus <- function(file, sep = "", input = NULL, print = FALSE, return.var =
 
       #......
       # Number of columns match with number of variable names
-      if (!is.null(input)) {
+      if (isTRUE(!is.null(input))) {
 
         df.check <- read.table(file, fileEncoding = fileEncoding,
                                stringsAsFactors = FALSE)
 
-        if (ncol(df.check) != length(varnames)) {
+        if (isTRUE(ncol(df.check) != length(varnames))) {
 
           # Print variable names on console
           if (isTRUE(print)) {
@@ -211,7 +250,7 @@ read.mplus <- function(file, sep = "", input = NULL, print = FALSE, return.var =
     #----------------------------------------
     # Assign variable names
 
-    if (!is.null(input)) {
+    if (isTRUE(!is.null(input))) {
 
       colnames(object) <- varnames
 
